@@ -10,6 +10,15 @@ use Plack::Request;
 
 Plack::App::RDF::LinkedData - A Plack application for running RDF::LinkedData
 
+=head1 VERSION
+
+Version 1.02
+
+=cut
+
+ our $VERSION = '1.02';
+
+
 =head1 SYNOPSIS
 
   my $linkeddata = Plack::App::RDF::LinkedData->new();
@@ -121,7 +130,11 @@ work-in-progress, It is a more lightweight but less powerful way to
 query RDF data than SPARQL. If you have this, it is recommended to
 have CORS enabled and required to have at least a minimal VoID setup.
 
-
+Note that in some environments, for example if the Plack server
+is dynamically configured and/or behind a proxy server, the server
+may fail to bind to the address you give it as hostname. In this case,
+it is wise to allow the server to bind to any public IP address,
+i.e. set the host name to 0.0.0.0.
 
 =head2 Details of the implementation
 
@@ -129,17 +142,21 @@ This server is a minimal Plack-script that should be sufficient for
 most linked data usages, and serve as a an example for most others.
 
 A minimal example of the required config file is provided above. There
-is are longer examples in the distribtion, which is used to run
+is are longer examples in the distribution, which is used to run
 tests. In the config file, there is a C<store> parameter, which must
 contain the L<RDF::Trine::Store> config hashref. It may also have a
 C<base_uri> URI and a C<namespace> hashref which may contain prefix -
-URI mappings to be used in serializations.
+URI mappings to be used in serializations. Certain namespace, namely
+RDF, VoID, Hydra, DC Terms and XML Schema are added by the module and
+do not need to be declared.
+
 
 Note that this is a server that can only serve URIs of hosts you
 control, it is not a general purpose Linked Data manipulation tool,
-nor is it a full implementation of the L<Linked Data API|http://code.google.com/p/linked-data-api/>.
+nor is it an implementation of Linked Data Platform or the Linked Data
+API.
 
-The configuration is done using L<Config::JFDI> and all its features
+The configuration is done using L<Config::ZOMG> and all its features
 can be used. Importantly, you can set the C<RDF_LINKEDDATA_CONFIG>
 environment variable to point to the config file you want to use. See
 also L<Catalyst::Plugin::ConfigLoader> for more information on how to
@@ -147,8 +164,8 @@ use this config system.
 
 =head2 Behaviour
 
-The following documentation is adapted from the L<RDF::LinkedData::Apache>,
-which preceeded this script.
+The following documentation is adapted from RDF::LinkedData::Apache,
+which preceded this module.
 
 =over 4 
 
@@ -201,7 +218,7 @@ you may have to install it separately. It has many configuration
 options, please see its documentation for details.
 
 You may also need to set the C<RDF_ENDPOINT_SHAREDIR> variable to
-whereever the endpoint shared files are installed to. These are some
+wherever the endpoint shared files are installed to. These are some
 CSS and Javascript files that enhance the user experience. They are
 not strictly necessary, but it sure makes it pretty! L<RDF::Endpoint>
 should do the right thing, though, so it shouldn't be necessary.
@@ -241,8 +258,8 @@ By adding an C<add_void> config key, you can make pass a file to the
 generator so that arbitrary RDF can be added to the VoID
 description. It will check the last modification time of the file and
 only update the VoID description if it has been modified. This is
-usefil since as much of the VoID description cannot be simply
-generated. To use it, the configuration would in JSON look something
+useful since as much of the VoID description is expensive to
+compute. To use it, the configuration would in JSON look something
 like this:
 
 	"add_void": { "file": "/data/add.ttl", "syntax": "turtle" }
@@ -307,6 +324,9 @@ sub prepare_app {
 															 base_uri => $config->{base_uri}
 															);
 	$self->{linkeddata}->namespaces(URI::NamespaceMap->new($config->{namespaces})) if ($config->{namespaces});
+	# Ensure that certain namespaces are always declared
+	$self->{linkeddata}->guess_namespaces('rdf', 'dc', 'xsd', 'void');
+	$self->{linkeddata}->add_namespace_mapping(hydra => 'http://www.w3.org/ns/hydra/core#');
 }
 
 sub call {
@@ -345,7 +365,7 @@ Kjetil Kjernsmo, C<< <kjetilk@cpan.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010,2011,2012,2013,2014 Kjetil Kjernsmo
+Copyright 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 Kjetil Kjernsmo
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
